@@ -2,7 +2,7 @@ package Config::IniFiles;
 
 use vars qw($VERSION);
 
-$VERSION = "2.45";
+$VERSION = "2.46";
 
 require 5.004;
 use strict;
@@ -1457,7 +1457,17 @@ sub GetSectionComment
 	}
 	
 	if (exists $self->{sCMT}{$sect}) {
-		return @{$self->{sCMT}{$sect}};
+		my @ret = @{$self->{sCMT}{$sect}};
+        if (wantarray()) {
+            return @ret;
+        }
+        else {
+            if (defined ($/)) {
+                return join "$/", @ret;
+            } else {
+                return join "\n", @ret;
+            }
+        }
 	} else {
 		return undef;
 	}
@@ -1523,7 +1533,8 @@ sub SetParameterComment
 
 =head2 GetParameterComment ($section, $parameter)
 
-Gets the comment attached to a parameter.
+Gets the comment attached to a parameter. In list context returns all
+comments - in scalar context returns them joined by newlines.
 
 =cut
 
@@ -1545,7 +1556,7 @@ sub GetParameterComment
 	exists($self->{pCMT}{$sect}{$parm}) || return undef;
 	
 	my @comment = @{$self->{pCMT}{$sect}{$parm}};
-	return (wantarray)?@comment:join " ", @comment;
+	return wantarray() ? @comment : join((defined $/ ? $/ : "\n"), @comment);
 }
 
 =head2 DeleteParameterComment ($section, $parmeter)
